#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.1.24
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org


%define pa_ver_full %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)
%define pa_ver_major_minor %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1 | cut -d "." -f 1,2)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXfixes-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 15.0
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-devel
BuildRequires:	qubes-gui-common-devel >= 4.1.0
BuildRequires:	qubes-db-devel
BuildRequires:	xen-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	libXfixes
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
Requires:	qubes-libvchan
# qubesdb-read --wait option
Requires:	qubes-db >= 4.1.4
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-server-Xorg
Requires:   xorg-x11-server-Xephyr
Requires:   setxkbmap
Requires:   xsetroot
Requires:   xrdb
Requires:   xmodmap
Requires:   xev
Requires:   xdpyinfo
Requires:   xprop
Requires:   xrandr

Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver_full}
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%package -n qubes-gui-vnc
Summary: Remote GuiVM support using VNC
Requires: x11vnc

%description -n qubes-gui-vnc
Remote GuiVM support using VNC

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver_full} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make appvm

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER_FULL=%{pa_ver_full}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

if [ -d '/etc/init.d' ] && ! [ "$(ls -A /etc/init.d/ 2> /dev/null)" ]; then
    rmdir /etc/init.d
fi

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}


%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-run-xephyr
/usr/bin/qubes-start-xephyr
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%{_libdir}/libxf86-qubes-common.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/X11/xinit/xinitrc.d/50guivm-windows-prefix.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
/etc/qubes-rpc/qubes.GuiVMSession
/etc/qubes/post-install.d/20-qubes-guivm-gui-agent.sh
%config /etc/sysconfig/desktop
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
/usr/lib/qubes/qubes-gui-agent-pre.sh
/usr/lib/qubes/qubes-keymap.sh
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
/etc/xdg/autostart/qubes-qrexec-fork-server.desktop
/etc/xdg/autostart/qubes-keymap.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{_libdir}/pulse-%{pa_ver_major_minor}/modules/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop

%files xfce
/etc/X11/xinit/xinitrc.d/60xfce-desktop.sh

%files -n qubes-gui-vnc
#/lib/systemd/system/qubes-gui-vncserver.service
%attr(0644,root,root) /etc/X11/xorg-qubes-x11vnc.conf.template
%attr(0644,root,root) /etc/systemd/system/lightdm.service.d/qubes-guivm-vnc.conf
/usr/bin/qubes-run-x11vnc

%changelog
* Thu Jan 06 2022 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux.git

* Thu Jan 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e7fa684
- version 4.1.24

* Thu Jan 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0fa4e24
- archlinux: bump xorg ABI version requirements

* Tue Nov 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7caf286
- version 4.1.23

* Thu Oct 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - d6d74fc
- Fix minor problems

* Thu Oct 21 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 1cd3b7b
- Ensure that no subwindows are created

* Tue Sep 28 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ca265a
- Fix XEMBED_EMBEDDED_NOTIFY parameters

* Tue Aug 24 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 33cf99d
- version 4.1.22

* Sun Aug 01 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 63c9de3
- pulse: set module version to the PA version

* Thu Jul 29 2021 fepitre-bot <fepitre-bot@qubes-os.org> - 5da31c7
- Add pulseaudio-15.0 headers

* Sat Jul 10 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 43978ae
- version 4.1.21

* Sat Jul 10 2021 Nedyalko Andreev <n@andreev.sh> - 35ae44f
- Fix support for non-latin variants when we append the us layout

* Fri Jul 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1ce1437
- version 4.1.20

* Fri Jul 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 4fafcb0
- Fix the name of WM_DELETE_WINDOW

* Wed Jul 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 59ddfd3
- Fix getting all the required atoms

* Wed Jul 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 65d3025
- Fix tray message opcode

* Tue Jul 06 2021 Ivan Kardykov <kardykov@tabit.pro> - 9ad3964
- Always keep latin keyboard layout

* Mon Jul 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 36142f9
- rpm: add xrandr dependency

* Thu Jul 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - d5a3dbb
- Use XInternAtoms() more

* Thu Jul 01 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - eec081f
- Crash if snprintf() fails

* Thu Jul 01 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ea1552f
- version 4.1.19

* Tue Jun 29 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - fb74963
- Failure to intern MANAGER atom is fatal

* Tue Jun 29 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - a9ae645
- Use ternary operator to simplify some code

* Tue Jun 29 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 2d58ffd
- Remove the last XInternAtom call after startup

* Sun Jun 27 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6ee20f5
- spec: remove xorg-x11-utils and replace by dependencies

* Wed Jun 23 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7b0d08e
- Use only one script for pre and post

* Tue Jun 22 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - b6556b3
- guivm-vnc: add few comments for pre script

* Tue Jun 22 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7d5b10f
- guivm-vnc: simplify options set

* Tue Jun 22 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e01ecdd
- guivm-vnc: use /run directly in lightdm preset conf

* Tue Jun 22 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - eab7854
- Implement VNC GuiVM

* Sat Jun 12 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e201e39
- version 4.1.18

* Sat May 15 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - aa7f3d7
- spec: ensure R for few x11 tools

* Mon Apr 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b1c7f38
- version 4.1.17

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - bb38359
- get-latest-pulsecore: default value for latest Fedora release

* Sun Mar 07 2021 Rusty Bird <rustybird@net-c.com> - 0b5f831
- vmside: make strncat() length more obvious

* Sat Feb 13 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f825ad9
- version 4.1.16

* Mon Jan 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 291f697
- Add pulseaudio 14.2 headers

* Mon Jan 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 057bef2
- Add pulseaudio-14.1 headers

* Sun Jan 17 2021 unman <unman@thirdeyesecurity.org> - f9f03ba
- Fix pulseaudio in Ubuntu templates

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ac6778d
- debian: prevent restart on update

* Tue Jan 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3d2e1cd
- version 4.1.15

* Thu Dec 31 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 56f1b43
- Mass replace: ‘/var/run’ → ‘/run’

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - ac6b71e
- Remove unneded time parameters

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - ab398bd
- Avoid passing NULL as an X11 string

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 6a5378c
- Remove references to /tmp/qubes-session-{env,waiter}

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 14e93a5
- Tell Java we are a non-reparenting window manager

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - f84093a
- Only set focus on windows that want it

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - cc2a426
- Use actual X11 timestamps

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 19ce958
- Delete commented-out code

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 7391391
- Add Vim modeline

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 39da627
- Log when an unmanaged window is skipped

